@@ -2,33 +2,28 @@
 ### Encoding: UTF-8
 
 ###################################################
-### code chunk number 1: stream.Rnw:135-136
+### code chunk number 1: stream.Rnw:136-137
 ###################################################
 options(width = 75, digits = 3, prompt = 'R> ', scipen = 3)
 
 
 ###################################################
-### code chunk number 2: stream.Rnw:649-650
-###################################################
-set.seed(1000)
-
-
-###################################################
-### code chunk number 3: stream.Rnw:653-655
+### code chunk number 2: stream.Rnw:652-655
 ###################################################
 library("stream")
+set.seed(1000)
 stream <- DSD_Gaussians(k = 3, d = 2)
 
 
 ###################################################
-### code chunk number 4: stream.Rnw:664-666
+### code chunk number 3: stream.Rnw:664-666
 ###################################################
 dstream <- DSC_DStream(gridsize = .1, Cm = 1.2)
 update(dstream, stream, n = 500)
 
 
 ###################################################
-### code chunk number 5: initial_example
+### code chunk number 4: initial_example
 ###################################################
 km <- DSC_Kmeans(k = 3)
 recluster(km, dstream)
@@ -36,61 +31,51 @@ plot(km, stream, type = "both")
 
 
 ###################################################
-### code chunk number 6: stream.Rnw:882-883
-###################################################
-set.seed(1000) 
-
-
-###################################################
-### code chunk number 7: stream.Rnw:885-889
+### code chunk number 5: stream.Rnw:882-887
 ###################################################
 library("stream")
+set.seed(1000) 
 
 stream <- DSD_Gaussians(k = 3, d = 3, noise = .05, p = c(.5, .3, .1)) 
 stream
 
 
 ###################################################
-### code chunk number 8: stream.Rnw:910-912
+### code chunk number 6: stream.Rnw:908-910
 ###################################################
 p <- get_points(stream, n = 5) 
 p 
 
 
 ###################################################
-### code chunk number 9: stream.Rnw:923-925
+### code chunk number 7: stream.Rnw:921-923
 ###################################################
 p <- get_points(stream, n = 100, class = TRUE) 
 head(p, n = 10)
 
 
 ###################################################
-### code chunk number 10: static
+### code chunk number 8: static
 ###################################################
 plot(stream, n = 500)
 
 
 ###################################################
-### code chunk number 11: static_pc
+### code chunk number 9: static_pc
 ###################################################
 plot(stream, n = 500, method = "pc")
 
 
 ###################################################
-### code chunk number 12: stream.Rnw:975-976
+### code chunk number 10: moa1
 ###################################################
 set.seed(1000) 
-
-
-###################################################
-### code chunk number 13: moa1
-###################################################
 stream <- DSD_Benchmark(1)
 stream
 
 
 ###################################################
-### code chunk number 14: stream.Rnw:988-992 (eval = FALSE)
+### code chunk number 11: stream.Rnw:983-987 (eval = FALSE)
 ###################################################
 ## for(i in 1:4) {
 ##   plot(stream, 250, xlim = c(0, 1), ylim = c(0, 1))
@@ -99,7 +84,7 @@ stream
 
 
 ###################################################
-### code chunk number 15: moa1
+### code chunk number 12: moa1
 ###################################################
 plot(stream, 250, xlim = c(0, 1), ylim = c(0, 1))
 arrows(.15, .85, .85, .15, col = rgb(.8, .8, .8, .6), lwd = 10)
@@ -108,7 +93,7 @@ tmp <- get_points(stream, n = 1400)
 
 
 ###################################################
-### code chunk number 16: moa2
+### code chunk number 13: moa2
 ###################################################
 plot(stream, 250, xlim = c(0, 1), ylim = c(0, 1))
 arrows(.15, .85, .85, .15, col = rgb(.8, .8, .8, .6), lwd = 10)
@@ -117,7 +102,7 @@ tmp <- get_points(stream, n=1400)
 
 
 ###################################################
-### code chunk number 17: moa3
+### code chunk number 14: moa3
 ###################################################
 plot(stream, 250, xlim = c(0, 1), ylim = c(0, 1))
 arrows(.15,.85,.85,.15, col=rgb(.8,.8,.8,.6), lwd=10)
@@ -126,7 +111,7 @@ tmp <- get_points(stream, n=1400)
 
 
 ###################################################
-### code chunk number 18: moa4
+### code chunk number 15: moa4
 ###################################################
 plot(stream, 250, xlim=c(0,1), ylim=c(0,1))
 arrows(.15,.85,.85,.15, col=rgb(.8,.8,.8,.6), lwd=10)
@@ -134,7 +119,7 @@ arrows(.15,.15,.85,.85, col=rgb(.8,.8,.8,.6), lwd=10)
 
 
 ###################################################
-### code chunk number 19: stream.Rnw:1044-1047 (eval = FALSE)
+### code chunk number 16: stream.Rnw:1039-1042 (eval = FALSE)
 ###################################################
 ## reset_stream(stream)
 ## animate_data(stream, n = 10000, horizon = 100, 
@@ -142,7 +127,7 @@ arrows(.15,.15,.85,.85, col=rgb(.8,.8,.8,.6), lwd=10)
 
 
 ###################################################
-### code chunk number 20: stream.Rnw:1053-1056 (eval = FALSE)
+### code chunk number 17: stream.Rnw:1048-1051 (eval = FALSE)
 ###################################################
 ## library("animation")
 ## animation::ani.options(interval = .1)
@@ -150,33 +135,28 @@ arrows(.15,.15,.85,.85, col=rgb(.8,.8,.8,.6), lwd=10)
 
 
 ###################################################
-### code chunk number 21: stream.Rnw:1063-1065 (eval = FALSE)
+### code chunk number 18: stream.Rnw:1058-1060 (eval = FALSE)
 ###################################################
 ## saveHTML(ani.replay())
 ## saveGIF(ani.replay())
 
 
 ###################################################
-### code chunk number 22: stream.Rnw:1089-1090
-###################################################
-set.seed(1000) 
-
-
-###################################################
-### code chunk number 23: stream.Rnw:1092-1094
+### code chunk number 19: stream.Rnw:1084-1087
 ###################################################
 library("stream") 
+set.seed(1000) 
 stream <- DSD_Gaussians(k = 3, d = 5) 
 
 
 ###################################################
-### code chunk number 24: stream.Rnw:1099-1100 (eval = FALSE)
+### code chunk number 20: stream.Rnw:1092-1093 (eval = FALSE)
 ###################################################
 ## write_stream(stream, "data.csv", n = 100, sep = ",") 
 
 
 ###################################################
-### code chunk number 25: stream.Rnw:1130-1134
+### code chunk number 21: stream.Rnw:1123-1127
 ###################################################
 file <- system.file("examples", "kddcup10000.data.gz", package = "stream")
 stream_file <- DSD_ReadCSV(gzfile(file),
@@ -185,141 +165,124 @@ stream_file
 
 
 ###################################################
-### code chunk number 26: stream.Rnw:1146-1147
+### code chunk number 22: stream.Rnw:1139-1140
 ###################################################
 get_points(stream_file, n = 5)
 
 
 ###################################################
-### code chunk number 27: stream.Rnw:1154-1156
+### code chunk number 23: stream.Rnw:1147-1149
 ###################################################
 stream_scaled <- DSD_ScaleStream(stream_file, center = TRUE, scale = TRUE)
 get_points(stream_scaled, n = 5)
 
 
 ###################################################
-### code chunk number 28: stream.Rnw:1186-1188
-###################################################
-library("stream") 
-set.seed(1000) 
-
-
-###################################################
-### code chunk number 29: stream.Rnw:1190-1192
+### code chunk number 24: stream.Rnw:1180-1182
 ###################################################
 data("EuStockMarkets", package = "datasets")
 head(EuStockMarkets)
 
 
 ###################################################
-### code chunk number 30: stream.Rnw:1199-1201
+### code chunk number 25: stream.Rnw:1189-1191
 ###################################################
 replayer <- DSD_Memory(EuStockMarkets, k = NA) 
 replayer 
 
 
 ###################################################
-### code chunk number 31: stream.Rnw:1207-1209
+### code chunk number 26: stream.Rnw:1197-1199
 ###################################################
 get_points(replayer, n = 5)
 replayer
 
 
 ###################################################
-### code chunk number 32: stream.Rnw:1217-1218 (eval = FALSE)
+### code chunk number 27: stream.Rnw:1207-1208 (eval = FALSE)
 ###################################################
 ## get_points(replayer, n = 2000)
 
 
 ###################################################
-### code chunk number 33: stream.Rnw:1220-1222
+### code chunk number 28: stream.Rnw:1210-1212
 ###################################################
 err <- try(get_points(replayer, n = 2000))
 cat(err)
 
 
 ###################################################
-### code chunk number 34: stream.Rnw:1236-1238
+### code chunk number 29: stream.Rnw:1226-1228
 ###################################################
 reset_stream(replayer, pos = 100)
 replayer
 
 
 ###################################################
-### code chunk number 35: stream.Rnw:1544-1545
-###################################################
-set.seed(1000) 
-
-
-###################################################
-### code chunk number 36: stream.Rnw:1548-1550
+### code chunk number 30: stream.Rnw:1534-1537
 ###################################################
 library("stream") 
+set.seed(1000) 
 stream <- DSD_Gaussians(k = 3, d = 2, noise = .05)
 
 
 ###################################################
-### code chunk number 37: stream.Rnw:1558-1560
+### code chunk number 31: stream.Rnw:1545-1547
 ###################################################
 dstream <- DSC_DStream(gridsize = .1, Cm = 1.2) 
 dstream
 
 
 ###################################################
-### code chunk number 38: stream.Rnw:1568-1570
+### code chunk number 32: stream.Rnw:1555-1557
 ###################################################
 update(dstream, stream, n = 500) 
 dstream
 
 
 ###################################################
-### code chunk number 39: stream.Rnw:1579-1580
+### code chunk number 33: stream.Rnw:1566-1567
 ###################################################
 head(get_centers(dstream))
 
 
 ###################################################
-### code chunk number 40: cluster
+### code chunk number 34: cluster
 ###################################################
 plot(dstream, stream)
 
 
 ###################################################
-### code chunk number 41: cluster-grid
+### code chunk number 35: cluster-grid
 ###################################################
 plot(dstream, stream, grid = TRUE)
 
 
 ###################################################
-### code chunk number 42: stream.Rnw:1888-1892
+### code chunk number 36: stream.Rnw:1887-1891
 ###################################################
 library("stream") 
 stream <- DSD_Gaussians(k = 3, d = 2, noise = .05)
 dstream <- DSC_DStream(gridsize = .1) 
-update(dstream, stream, n = 1000) 
+update(dstream, stream, n = 2000) 
 
 
 ###################################################
-### code chunk number 43: stream.Rnw:1900-1901
+### code chunk number 37: stream.Rnw:1899-1900
 ###################################################
 evaluate(dstream, stream, n = 100)
 
 
 ###################################################
-### code chunk number 44: stream.Rnw:1912-1913
+### code chunk number 38: stream.Rnw:1911-1912
 ###################################################
 evaluate(dstream, stream, measure = c("purity", "crand"), n = 500)
 
 
 ###################################################
-### code chunk number 45: stream.Rnw:1954-1955
+### code chunk number 39: stream.Rnw:1953-1959
 ###################################################
 set.seed(1000)
-
-
-###################################################
-### code chunk number 46: stream.Rnw:1957-1962
-###################################################
 stream <- DSD_Benchmark(1)
 dstream <- DSC_DStream(gridsize = .05, lambda = .01)
 ev <- evaluate_cluster(dstream, stream, 
@@ -328,37 +291,27 @@ head(ev)
 
 
 ###################################################
-### code chunk number 47: evaluation
+### code chunk number 40: evaluation
 ###################################################
 plot(ev[ , "points"], ev[ , "purity"], type = "l", 
   ylab = "Avg. Purity", xlab = "Points")
 
 
 ###################################################
-### code chunk number 48: stream.Rnw:1995-1996
-###################################################
-set.seed(1000)
-
-
-###################################################
-### code chunk number 49: stream.Rnw:1999-2003 (eval = FALSE)
+### code chunk number 41: stream.Rnw:1992-1997 (eval = FALSE)
 ###################################################
+## set.seed(1000)
 ## stream <- DSD_Benchmark(1)
 ## dstream <- DSC_DStream(gridsize = .05, lambda = .01)
 ## r <- animate_cluster(dstream, stream, horizon = 100, n = 5000, 
-##   measure = "purity", xlim = c(0, 1), ylim = c(0, 1))
+##      measure = "purity", plot.args = list(xlim = c(0, 1), ylim = c(0, 1)))
 
 
 ###################################################
-### code chunk number 50: stream.Rnw:2033-2034
-###################################################
-set.seed(1000) 
-
-
-###################################################
-### code chunk number 51: stream.Rnw:2037-2043
+### code chunk number 42: stream.Rnw:2027-2034
 ###################################################
 library("stream")
+set.seed(1000) 
 stream <- DSD_Gaussians(k = 3, d = 2, noise = .05)
 dstream <- DSC_DStream(gridsize = .05, Cm = 1.5)
 
@@ -367,13 +320,13 @@ dstream
 
 
 ###################################################
-### code chunk number 52: recluster
+### code chunk number 43: recluster
 ###################################################
 plot(dstream, stream, type = "both")
 
 
 ###################################################
-### code chunk number 53: recluster2
+### code chunk number 44: recluster2
 ###################################################
 km <- DSC_Kmeans(k = 3, weighted = TRUE)
 recluster(km, dstream)
@@ -382,20 +335,20 @@ plot(km, stream, type = "both")
 
 
 ###################################################
-### code chunk number 54: stream.Rnw:2104-2105
+### code chunk number 45: stream.Rnw:2095-2096
 ###################################################
 evaluate(km, stream, measure = c("purity", "crand", "SSQ"), n = 1000)
 
 
 ###################################################
-### code chunk number 55: stream.Rnw:2110-2112
+### code chunk number 46: stream.Rnw:2101-2103
 ###################################################
 evaluate(km, stream, c(measure = "purity", "crand", "SSQ"), n = 1000, 
   assign = "macro")
 
 
 ###################################################
-### code chunk number 56: stream.Rnw:2135-2138
+### code chunk number 47: stream.Rnw:2126-2129
 ###################################################
 points <- get_points(stream, n = 100)
 assignment <- get_assignment(dstream, points, type = "macro")
@@ -403,7 +356,7 @@ assignment
 
 
 ###################################################
-### code chunk number 57: silhouette
+### code chunk number 48: silhouette
 ###################################################
 assignment[is.na(assignment)] <- 0L
 library("cluster")
@@ -411,14 +364,9 @@ plot(silhouette(assignment, dist = dist(points)))
 
 
 ###################################################
-### code chunk number 58: stream.Rnw:2339-2340
+### code chunk number 49: data_bng
 ###################################################
 set.seed(1000) 
-
-
-###################################################
-### code chunk number 59: data_bng
-###################################################
 library("stream") 
 stream <- DSD_Memory(DSD_BarsAndGaussians(noise = .05), n = 1500)
 stream
@@ -426,7 +374,7 @@ plot(stream)
 
 
 ###################################################
-### code chunk number 60: stream.Rnw:2366-2374
+### code chunk number 50: stream.Rnw:2354-2362
 ###################################################
 algorithms <- list(
   'Sample' = DSC_TwoStage(micro = DSC_Sample(k = 100), 
@@ -439,7 +387,7 @@ algorithms <- list(
 
 
 ###################################################
-### code chunk number 61: stream.Rnw:2384-2388
+### code chunk number 51: stream.Rnw:2372-2376
 ###################################################
 for(a in algorithms) {
   reset_stream(stream) 
@@ -448,13 +396,13 @@ for(a in algorithms) {
 
 
 ###################################################
-### code chunk number 62: stream.Rnw:2393-2394
+### code chunk number 52: stream.Rnw:2381-2382
 ###################################################
 sapply(algorithms, nclusters, type = "micro")
 
 
 ###################################################
-### code chunk number 63: microclusters
+### code chunk number 53: microclusters
 ###################################################
 op <- par(no.readonly = TRUE)
 layout(mat = matrix(1:length(algorithms), ncol = 2))
@@ -466,7 +414,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 64: microclusters_assignment
+### code chunk number 54: microclusters_assignment
 ###################################################
 op <- par(no.readonly = TRUE)
 layout(mat = matrix(1:length(algorithms), ncol = 2))
@@ -479,7 +427,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 65: stream.Rnw:2472-2479
+### code chunk number 55: stream.Rnw:2460-2467
 ###################################################
 sapply(algorithms, FUN=function(a) {
   reset_stream(stream, pos = 1001) 
@@ -491,7 +439,7 @@ sapply(algorithms, FUN=function(a) {
 
 
 ###################################################
-### code chunk number 66: macroclusters
+### code chunk number 56: macroclusters
 ###################################################
 op <- par(no.readonly = TRUE)
 layout(mat=matrix(1:length(algorithms), ncol = 2))
@@ -503,7 +451,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 67: stream.Rnw:2523-2529
+### code chunk number 57: stream.Rnw:2511-2517
 ###################################################
 sapply(algorithms, FUN = function(a) {
   reset_stream(stream, pos = 1001) 
@@ -514,19 +462,14 @@ sapply(algorithms, FUN = function(a) {
 
 
 ###################################################
-### code chunk number 68: stream.Rnw:2550-2551
+### code chunk number 58: stream.Rnw:2539-2541
 ###################################################
 set.seed(0)
-
-
-###################################################
-### code chunk number 69: stream.Rnw:2554-2555
-###################################################
 stream <- DSD_Memory(DSD_Benchmark(1), n = 5000)
 
 
 ###################################################
-### code chunk number 70: stream.Rnw:2565-2573
+### code chunk number 59: stream.Rnw:2551-2559
 ###################################################
 algorithms <- list(
   'Sample' = DSC_TwoStage(micro = DSC_Sample(k = 100, biased = TRUE), 
@@ -539,7 +482,7 @@ algorithms <- list(
 
 
 ###################################################
-### code chunk number 71: stream.Rnw:2584-2589
+### code chunk number 60: stream.Rnw:2570-2575
 ###################################################
 evaluation <- lapply(algorithms, FUN = function(a) {
   reset_stream(stream) 
@@ -549,7 +492,7 @@ evaluation <- lapply(algorithms, FUN = function(a) {
 
 
 ###################################################
-### code chunk number 72: stream.Rnw:2605-2608
+### code chunk number 61: stream.Rnw:2591-2594
 ###################################################
 Position <- evaluation[[1]][ , "points"]
 cRand <- sapply(evaluation, FUN = function(x) x[ , "cRand"])
@@ -557,7 +500,7 @@ head(cRand)
 
 
 ###################################################
-### code chunk number 73: dynamic
+### code chunk number 62: dynamic
 ###################################################
 matplot(Position, cRand, type = "l", lwd = 2)
 legend("bottomleft", legend = names(evaluation), 
@@ -565,13 +508,13 @@ legend("bottomleft", legend = names(evaluation),
 
 
 ###################################################
-### code chunk number 74: dynamic_box
+### code chunk number 63: dynamic_box
 ###################################################
 boxplot(cRand, las = 2, cex.axis = .8)
 
 
 ###################################################
-### code chunk number 75: stream.Rnw:2666-2674 (eval = FALSE)
+### code chunk number 64: stream.Rnw:2652-2660 (eval = FALSE)
 ###################################################
 ## library("stream")
 ## con <- gzcon(
@@ -584,7 +527,7 @@ boxplot(cRand, las = 2, cex.axis = .8)
 
 
 ###################################################
-### code chunk number 76: stream.Rnw:2680-2682 (eval = FALSE)
+### code chunk number 65: stream.Rnw:2666-2668 (eval = FALSE)
 ###################################################
 ## dstream <- DSC_DStream(gridsize = .5, gaptime = 10000L, lambda = .01)
 ## update(dstream, stream2, n = 4000000, verbose = TRUE)
